@@ -36,7 +36,7 @@
 #include "libavutil/detection_bbox.h"
 #include "avfilter.h"
 #include "drawutils.h"
-#include "internal.h"
+#include "filters.h"
 #include "video.h"
 
 static const char *const var_names[] = {
@@ -454,7 +454,7 @@ static const AVOption drawbox_options[] = {
     { "thickness", "set the box thickness",                        OFFSET(t_expr),    AV_OPT_TYPE_STRING, { .str="3" },       0, 0, FLAGS },
     { "t",         "set the box thickness",                        OFFSET(t_expr),    AV_OPT_TYPE_STRING, { .str="3" },       0, 0, FLAGS },
     { "replace",   "replace color & alpha",                        OFFSET(replace),   AV_OPT_TYPE_BOOL,   { .i64=0   },       0, 1, FLAGS },
-    { "box_source", "use datas from bounding box in side data",    OFFSET(box_source_string), AV_OPT_TYPE_STRING, { .str=NULL }, 0, 1, FLAGS },
+    { "box_source","use data from bounding box in side data",      OFFSET(box_source_string), AV_OPT_TYPE_STRING, { .str=NULL }, 0, 1, FLAGS },
     { NULL }
 };
 
@@ -470,17 +470,17 @@ static const AVFilterPad drawbox_inputs[] = {
     },
 };
 
-const AVFilter ff_vf_drawbox = {
-    .name          = "drawbox",
-    .description   = NULL_IF_CONFIG_SMALL("Draw a colored box on the input video."),
+const FFFilter ff_vf_drawbox = {
+    .p.name        = "drawbox",
+    .p.description = NULL_IF_CONFIG_SMALL("Draw a colored box on the input video."),
+    .p.priv_class  = &drawbox_class,
+    .p.flags       = AVFILTER_FLAG_SUPPORT_TIMELINE_GENERIC,
     .priv_size     = sizeof(DrawBoxContext),
-    .priv_class    = &drawbox_class,
     .init          = init,
     FILTER_INPUTS(drawbox_inputs),
     FILTER_OUTPUTS(ff_video_default_filterpad),
     FILTER_PIXFMTS_ARRAY(pix_fmts),
     .process_command = process_command,
-    .flags         = AVFILTER_FLAG_SUPPORT_TIMELINE_GENERIC,
 };
 #endif /* CONFIG_DRAWBOX_FILTER */
 
@@ -545,16 +545,16 @@ static const AVFilterPad drawgrid_inputs[] = {
     },
 };
 
-const AVFilter ff_vf_drawgrid = {
-    .name          = "drawgrid",
-    .description   = NULL_IF_CONFIG_SMALL("Draw a colored grid on the input video."),
+const FFFilter ff_vf_drawgrid = {
+    .p.name        = "drawgrid",
+    .p.description = NULL_IF_CONFIG_SMALL("Draw a colored grid on the input video."),
+    .p.priv_class  = &drawgrid_class,
+    .p.flags       = AVFILTER_FLAG_SUPPORT_TIMELINE_GENERIC,
     .priv_size     = sizeof(DrawBoxContext),
-    .priv_class    = &drawgrid_class,
     .init          = init,
     FILTER_INPUTS(drawgrid_inputs),
     FILTER_OUTPUTS(ff_video_default_filterpad),
     FILTER_PIXFMTS_ARRAY(pix_fmts),
-    .flags         = AVFILTER_FLAG_SUPPORT_TIMELINE_GENERIC,
     .process_command = process_command,
 };
 
